package com.jiuqi.grid;

import com.jiuqi.util.Stream;
import com.jiuqi.util.StreamException;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/* loaded from: com_jiuqi_grid.jar:com/jiuqi/grid/ValueList.class */
public class ValueList implements Serializable {
    private List list = new ArrayList();
    private List extList = new ArrayList();
    private static final int MaxWordSign = 65535;

    public String get(int index) {
        return ((CellValue) this.list.get(index)).value;
    }

    public int add(CellValue cv) {
        this.list.add(cv);
        if (cv.col > MaxWordSign || cv.row > MaxWordSign) {
            this.extList.add(cv);
        }
        return this.list.size() - 1;
    }

    public int col(int index) {
        return ((CellValue) this.list.get(index)).col;
    }

    public int row(int index) {
        return ((CellValue) this.list.get(index)).row;
    }

    public int count() {
        return this.list.size();
    }

    public void clear() {
        this.extList.clear();
        this.list.clear();
    }

    public CellValue find(int col, int row) {
        for (int i = 0; i < this.list.size(); i++) {
            CellValue cv = (CellValue) this.list.get(i);
            if (cv.col == col && cv.row == row) {
                return cv;
            }
        }
        return null;
    }

    public void loadFromStream(Stream stream) throws StreamException {
        clear();
        int c = stream.readInt();
        for (int i = 0; i < c; i++) {
            CellValue cv = new CellValue();
            cv.col = stream.readWord();
            cv.row = stream.readWord();
            int l = stream.readWord();
            if (l == MaxWordSign) {
                l = stream.readInt();
            }
            cv.value = stream.readString(l);
            this.list.add(cv);
        }
        if (stream.getPosition() + 4 <= stream.getSize()) {
            int c2 = stream.readInt();
            for (int i2 = 0; i2 < c2; i2++) {
                CellValue cv2 = new CellValue();
                cv2.col = stream.readInt();
                cv2.row = stream.readInt();
                int l2 = stream.readWord();
                if (l2 == MaxWordSign) {
                    l2 = stream.readInt();
                }
                cv2.value = stream.readString(l2);
                this.list.add(cv2);
                this.extList.add(cv2);
            }
        }
    }

    public void saveToStream(Stream stream) throws StreamException {
        stream.writeInt(this.list.size() - this.extList.size());
        for (int i = 0; i < this.list.size(); i++) {
            CellValue cv = (CellValue) this.list.get(i);
            if (cv.col <= MaxWordSign && cv.row <= MaxWordSign) {
                stream.writeWord(cv.col);
                stream.writeWord(cv.row);
                if (cv.value != null && cv.value.length() > 0) {
                    byte[] b = cv.value.getBytes();
                    if (b.length < MaxWordSign) {
                        stream.writeWord(b.length);
                    } else {
                        stream.writeWord(MaxWordSign);
                        stream.writeInt(b.length);
                    }
                    stream.writeBuffer(b, 0, b.length);
                } else {
                    stream.writeWord(0);
                }
            }
        }
        if (this.extList.size() != 0) {
            stream.writeInt(this.extList.size());
            for (int i2 = 0; i2 < this.extList.size(); i2++) {
                CellValue cv2 = (CellValue) this.extList.get(i2);
                stream.writeInt(cv2.col);
                stream.writeInt(cv2.row);
                if (cv2.value != null && cv2.value.length() > 0) {
                    byte[] b2 = cv2.value.getBytes();
                    if (b2.length < MaxWordSign) {
                        stream.writeWord(b2.length);
                    } else {
                        stream.writeWord(MaxWordSign);
                        stream.writeInt(b2.length);
                    }
                    stream.writeBuffer(b2, 0, b2.length);
                } else {
                    stream.writeWord(0);
                }
            }
        }
    }
}
